==> haskell-prettyprinter-interp-0.2.0.0-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-interp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-interp
version:              0.2.0.0
visibility:           public
id:                   prettyprinter-interp-0.2.0.0-JgkskRhWnh0L4n7m3sGWdu
key:                  prettyprinter-interp-0.2.0.0-JgkskRhWnh0L4n7m3sGWdu
license:              BSD-2-Clause
copyright:            (C) 2022-2023, Peter Lebbing
maintainer:           peter@digitalbrains.com
author:               Peter Lebbing
homepage:             https://github.com/DigitalBrains1/prettyprinter-interp
synopsis:             Efficient interpolation for Prettyprinter
description:
    This package provides efficient interpolation
    of @[string-interpolate](https://hackage.haskell.org/package/string-interpolate)@
    quasi quoters when used
    with @[prettyprinter](https://hackage.haskell.org/package/prettyprinter)@.

category:             Data, Text
abi:                  e51524d1148d28d6b514fa52782eb7e3
exposed:              True
exposed-modules:      Prettyprinter.Interpolate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-interp
hs-libraries:         HSprettyprinter-interp-0.2.0.0-JgkskRhWnh0L4n7m3sGWdu
depends:
    base-4.17.2.1 prettyprinter-1.7.1-5cxpZ3jZU7h3nFjq43pkKP
    string-interpolate-0.3.4.0-1Ft7WgihqJ94RGhte5nKwk
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-interp/html/prettyprinter-interp.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-interp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-interp-0.2.0.0-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-interp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-interp
version:              0.2.0.0
visibility:           public
id:                   prettyprinter-interp-0.2.0.0-Fc3gvHwdWDNLO1ZkzraqD
key:                  prettyprinter-interp-0.2.0.0-Fc3gvHwdWDNLO1ZkzraqD
license:              BSD-2-Clause
copyright:            (C) 2022-2023, Peter Lebbing
maintainer:           peter@digitalbrains.com
author:               Peter Lebbing
homepage:             https://github.com/DigitalBrains1/prettyprinter-interp
synopsis:             Efficient interpolation for Prettyprinter
description:
    This package provides efficient interpolation
    of @[string-interpolate](https://hackage.haskell.org/package/string-interpolate)@
    quasi quoters when used
    with @[prettyprinter](https://hackage.haskell.org/package/prettyprinter)@.

category:             Data, Text
abi:                  e9ce487c3c041ef6681a12789528f02f
exposed:              True
exposed-modules:      Prettyprinter.Interpolate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-interp
hs-libraries:         HSprettyprinter-interp-0.2.0.0-Fc3gvHwdWDNLO1ZkzraqD
depends:
    base-4.17.2.1 prettyprinter-1.7.1-27Ta3g9m3VQHgx6FjDiyXu
    string-interpolate-0.3.4.0-Fs3NJo8GY6NI3C0lZXBpFa
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-interp/html/prettyprinter-interp.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-interp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
